import { DVCClient as Client, DVCFeatureSet, DVCOptions, DVCVariableSet, DVCVariableValue, DVCEvent as ClientEvent, DVCUser, ErrorCallback, DVCFeature } from './types';
import { DVCVariable } from './Variable';
import { DVCPopulatedUser } from './User';
import { EventEmitter } from './EventEmitter';
import { BucketedUserConfig } from '@devcycle/types';
import { DVCLogger } from '@devcycle/types';
declare type variableUpdatedHandler = (key: string, variable: DVCVariable<DVCVariableValue> | null) => void;
declare type featureUpdatedHandler = (key: string, feature: DVCFeature | null) => void;
declare type newVariablesHandler = () => void;
declare type errorHandler = (error: unknown) => void;
declare type initializedHandler = (success: boolean) => void;
declare type configUpdatedHandler = (newVars: DVCVariableSet) => void;
export declare class DVCClient implements Client {
    private options;
    private onInitialized;
    private variableDefaultMap;
    private sdkKey;
    private userSaved;
    private _closing;
    private isConfigCached;
    logger: DVCLogger;
    config?: BucketedUserConfig;
    user: DVCPopulatedUser;
    private store;
    private eventQueue;
    private requestConsolidator;
    eventEmitter: EventEmitter;
    private streamingConnection?;
    private pageVisibilityHandler?;
    private inactivityHandlerId?;
    private windowMessageHandler?;
    constructor(sdkKey: string, user: DVCUser, options?: DVCOptions);
    onClientInitialized(): Promise<DVCClient>;
    onClientInitialized(onInitialized: ErrorCallback<DVCClient>): void;
    variable<T extends DVCVariableValue>(key: string, defaultValue: T): DVCVariable<T>;
    identifyUser(user: DVCUser): Promise<DVCVariableSet>;
    identifyUser(user: DVCUser, callback?: ErrorCallback<DVCVariableSet>): void;
    resetUser(): Promise<DVCVariableSet>;
    resetUser(callback: ErrorCallback<DVCVariableSet>): void;
    allFeatures(): DVCFeatureSet;
    allVariables(): DVCVariableSet;
    subscribe(key: `variableUpdated:${string}`, handler: variableUpdatedHandler): void;
    subscribe(key: `newVariables:${string}`, handler: newVariablesHandler): void;
    subscribe(key: `featureUpdated:${string}`, handler: featureUpdatedHandler): void;
    subscribe(key: 'error', handler: errorHandler): void;
    subscribe(key: 'initialized', handler: initializedHandler): void;
    subscribe(key: 'configUpdated', handler: configUpdatedHandler): void;
    unsubscribe(key: string, handler?: (...args: any[]) => void): void;
    track(event: ClientEvent): void;
    flushEvents(callback?: () => void): Promise<void>;
    close(): Promise<void>;
    get closing(): boolean;
    private refetchConfig;
    private handleConfigReceived;
    private onSSEMessage;
    private registerVisibilityChangeHandler;
    private getConfigCache;
    private initializeClient;
}
export {};
